# Software Bill of Materials

This package is licensed with the [``MIT License``](license.md)

## Runtime Dependencies
These are the dependencies required to run ``mkdocs_licenseinfo``:

### ::licenseinfo

## Development Dependencies
These are the dependencies required for developing ``mkdocs_licenseinfo``:

### ::licenseinfo
    using: PEP631:dev
    diff: PEP631

### Test Dependencies
#### ::licenseinfo
    using: PEP631:dev;dev-test
    diff: PEP631:dev

### Lint Dependencies
#### ::licenseinfo
    using: PEP631:dev;dev-lint
    diff: PEP631:dev

### Security Dependencies
#### ::licenseinfo
    using: PEP631:dev;dev-security
    diff: PEP631:dev

### Docs Dependencies
#### ::licenseinfo
    using: PEP631:dev;dev-docs
    diff: PEP631:dev

### Build Dependencies
#### ::licenseinfo
    using: PEP631:dev;dev-build
    diff: PEP631:dev
